import React from 'react'

const htmlPage = body => `<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
  </head>
  <body>
  ${body.trim()}
  </body>
</html>`

const example = {
  'Studio B': [
    ['8:30 - 9:30 ', 'Rhythm & Motion (Fusion)', 'Aimee Rose Zawitz'],
    ['10:00 - 11:15 ', 'Rhythm & Motion (Extended Fusion)', 'Dudley Flores'],
    ['10:30 - 12:00 ', 'Ballet - Advanced', 'Marika Brussel'],
    ['11:30 - 5:30 ', 'Maintenance', 'Keagan Chipp / ODC Theater'],
    ['12:00 - 5:00 ', 'ODC Theater', '. / Mohr'],
    ['1:00 - 2:00 ', 'Tap - Senior', 'Bruce Biada'],
    ['1:30 - 4:00 ', 'Rentals - Commons', '. / Wang'],
    ['2:00 - 3:00 ', 'Hula - Senior', 'Māhealani Uchiyama'],
    ['3:00 - 3:15 ', 'ODC School', 'Jill Lounibos / ODC School'],
    ['4:30 - 5:30 ', 'Rhythm & Motion (Modern)', 'Tamika Banks'],
    ['7:45 - 9:15 ', 'Belly Dance - Mixed Level 1 Technique Drills', 'Jill Parker'],
    ['8:30 - 9:45 ', 'House Dance Basics', 'JenAy'],
    ['8:45 - 9:45 ', 'Flamenco Choreography - Mixed Level', 'Kate McClure']
  ],
  Argyle: [
    ['8:45 - 10:00 ', 'Rhythm & Motion (Fusion Essentials)', 'Maggie Connard'],
    ['12:00 - 1:30 ', 'Rentals - Commons', '. / Damrow'],
    ['6:15 - 7:45 ', 'Ballet - Advanced Beginning', 'Marika Brussel'],
    ['6:45 - 8:15 ', 'Latin Dance Grooves', 'Elizabeth Soberanes'],
    ['7:15 - 9:45 ', 'Rentals - Commons', '. / Dekkers'],
    ['7:45 - 9:15 ', 'Resident Artist', '. / Kinetech Arts LAB'],
    ['9:15 - 11:55 ', 'HOLDS', '. / ODC School']
  ],
  Fisher: [
    ['9:00 - 10:00 ', 'Essentrics: Aging Backwards', 'Marika Brussel'],
    ['12:00 - 1:00 ', 'Rhythm & Motion RESET (Pay What You Can)', 'Heather Bornfeld'],
    ['4:00 - 5:45 ', 'Resident Artist', '. / Arrington'],
    ['5:45 - 6:45 ', 'Rhythm & Motion (Fusion)', 'Rena Marie Guidry'],
    ['7:45 - 8:45 ', 'Flamenco Technique - Mixed Level', 'Kate McClure']
  ],
  Skirball: [
    ['10:00 - 11:30 ', 'Hot Spot: Larry Arrington', 'Larry Arrington'],
    ['12:00 - 1:30 ', 'HOLDS', 'Jill Lounibos / ODC School'],
    ['5:45 - 7:45 ', 'HOLDS', 'Jill Lounibos / ODC School'],
    ['9:30 - 11:55 ', 'HOLDS', '. / ODC Theater']
  ],
  'Main Space': [['10:00 - 10:00 ', 'ODC Theater', '. / Mohr']],
  PC: [
    ['11:00 - 12:00 ', 'Rentals - Theater', '. / Wells'],
    ['9:30 - 11:55 ', 'HOLDS', '. / ODC Theater']
  ],
  Hellman: [['12:00 - 5:00 ', 'ODC Theater', '. / Mohr']],
  'Studio LP': [['12:00 - 5:00 ', 'ODC Theater', '. / Mohr']],
  'Comm. Conf.': [
    ['2:00 - 3:00 ', 'Rentals - Theater', '. / Wagner'],
    ['6:30 - 7:30 ', 'Rentals - Theater', '. / MacKenzie-Margulies'],
    ['9:30 - 11:55 ', 'HOLDS', '. / ODC Theater']
  ],
  Feintech: [
    ['5:30 - 8:30 ', 'Free Meetings', '. / Project Avary'],
    ['5:45 - 7:15 ', 'Contemporary - Advanced Beginning', 'Norma Fong'],
    ['6:30 - 8:30 ', 'Rentals - Theater', '. / Zawitz'],
    ['9:30 - 11:55 ', 'HOLDS', '. / ODC Theater']
  ],
  'Thtr. Conf.': [['5:30 - 6:30 ', 'Rentals - Theater', '. / Kendal']]
}

const x = [7, 8, 9, 10, 11, 12, 1, 2, 3, 4, 5, 6, 7, 8, 9].map(n => (
  <>
    <tr>
      <td>
        {n}:00 - {n}:30
      </td>
      <td> </td>
    </tr>
    <tr>
      <td>
        {n}:30 - {n === 12 ? 1 : n + 1}:00
      </td>
      <td> </td>
    </tr>
  </>
))

const Main = () => {
  const body = React.useRef(null)

  React.useEffect(() => {
    console.log(htmlPage(body.current.innerHTML))
  }, [])

  return (
    <div ref={body}>
      {Object.keys(example).map(key => (
        <div key={key} className="page">
          <h1>{key}</h1>
          <table>{x}</table>
        </div>
      ))}
      <style>
        {`
          :root {
            --light: white;

            --font-primary: -apple-system, Segoe UI, Roboto, Noto Sans, Ubuntu, Cantarell,
              Helvetica Neue, sans-serif;
          }
           
          * {
            box-sizing: border-box;
          }

          body {
            margin: 0;
            background: var(--light);
            font-variant-numeric: tabular-nums;
          }

          .page {
            height: 10in;
          }

          .row {
            display: flex;
          }

          .column {
            display: flex;
            flex-direction: column;
          }
          table {
            border: 1px solid black;
            border-spacing: 0px;
          }
          tr {
            height: 0.5in;
          }
          td {
            border: 1px solid black;
            padding: 0.125in;
          }
          tr td:nth-child(2) {
            width: 5in;

          }
        `}
      </style>
    </div>
  )
}

export default Main
